@@ -41,19 +41,19 @@ test_that("All cql geom predicate functions work", {
   }
   expect_equal(
     DWITHIN(the_geom, 1), #default units meters
-    CQL("DWITHIN({geom_name}, POINT (1 1), 1, 'meters')")
+    CQL("DWITHIN({geom_name}, POINT (1 1), 1, meters)")
   )
   expect_equal(
     DWITHIN(the_geom, 1, "meters"),
-    CQL("DWITHIN({geom_name}, POINT (1 1), 1, 'meters')")
+    CQL("DWITHIN({geom_name}, POINT (1 1), 1, meters)")
   )
   expect_equal(
     BEYOND(the_geom, 1, "feet"),
-    CQL("BEYOND({geom_name}, POINT (1 1), 1, 'feet')")
+    CQL("BEYOND({geom_name}, POINT (1 1), 1, feet)")
   )
   expect_equal(
     RELATE(the_geom, "*********"),
-    CQL("RELATE({geom_name}, POINT (1 1), '*********')")
+    CQL("RELATE({geom_name}, POINT (1 1), *********)")
   )
   expect_equal(
     BBOX(c(1,2,1,2)),
@@ -85,3 +85,11 @@ test_that("unsupported aggregation functions fail correctly", {
   expect_error(filter(structure(list(), class = "bcdc_promise"), mean(x) > 5),
                "not supported by this database")
 })
+
+test_that("passing an non-existent object to a geom predicate",{
+  skip_if_net_down()
+  skip_on_cran()
+  expect_error(bcdc_query_geodata("6a2fea1b-0cc4-4fc2-8017-eaf755d516da") %>%
+                 filter(INTERSECTS(districts)),
+               'object "districts" not found.\nThe object passed to INTERSECTS needs to be valid sf object.')
+})
